@@ -45,16 +45,26 @@ Settings *Settings::instance()
     return m_settings_instance;
 }
 
-bool Settings::stayOnTop()
+bool Settings::stayOnTop() const
 {
     return m_qsettings->value("stay_on_top", true).toBool();
 }
 
-bool Settings::useLightCheckerboard()
+bool Settings::useBuiltInCloseAnimation() const
+{
+    return m_qsettings->value("use_built_in_close_animation", true).toBool();
+}
+
+bool Settings::useLightCheckerboard() const
 {
     return m_qsettings->value("use_light_checkerboard", false).toBool();
 }
 
+bool Settings::loopGallery() const
+{
+    return m_qsettings->value("loop_gallery", true).toBool();
+}
+
 Settings::DoubleClickBehavior Settings::doubleClickBehavior() const
 {
     QString result = m_qsettings->value("double_click_behavior", "Close").toString();
@@ -89,12 +99,24 @@ void Settings::setStayOnTop(bool on)
     m_qsettings->sync();
 }
 
+void Settings::setUseBuiltInCloseAnimation(bool on)
+{
+    m_qsettings->setValue("use_built_in_close_animation", on);
+    m_qsettings->sync();
+}
+
 void Settings::setUseLightCheckerboard(bool light)
 {
     m_qsettings->setValue("use_light_checkerboard", light);
     m_qsettings->sync();
 }
 
+void Settings::setLoopGallery(bool on)
+{
+    m_qsettings->setValue("loop_gallery", on);
+    m_qsettings->sync();
+}
+
 void Settings::setDoubleClickBehavior(DoubleClickBehavior dcb)
 {
     m_qsettings->setValue("double_click_behavior", QEnumHelper::toString(dcb));
