@@ -4,42 +4,42 @@
 <context>
     <name>AboutDialog</name>
     <message>
-        <location filename="../aboutdialog.cpp" line="27"/>
+        <location filename="../aboutdialog.cpp" line="29"/>
         <source>About</source>
         <translation>Om</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="30"/>
+        <location filename="../aboutdialog.cpp" line="32"/>
         <source>Launch application with image file path as argument to load the file.</source>
         <translation>Kjør programmer ved å angi en filsti som argument for å laste inn filen.</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="31"/>
+        <location filename="../aboutdialog.cpp" line="33"/>
         <source>Drag and drop image file onto the window is also supported.</source>
         <translation>Å dra og slippe filen i vinduet støttes også.</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="32"/>
+        <location filename="../aboutdialog.cpp" line="34"/>
         <source>None of the operations in this application will alter the pictures on disk.</source>
         <translation>Ingen av operasjonene i dette programmet vil endre bildet som det er lagret.</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="33"/>
+        <location filename="../aboutdialog.cpp" line="35"/>
         <source>Context menu option explanation:</source>
         <translation>Forklaring av alternativer i bindeleddsmeny:</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="40"/>
+        <location filename="../aboutdialog.cpp" line="42"/>
         <source>Make window stay on top of all other windows.</source>
         <translation>Få vinduet til å alltid ligge over andre vinduer.</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="43"/>
+        <location filename="../aboutdialog.cpp" line="45"/>
         <source>Avoid close window accidentally. (eg. by double clicking the window)</source>
         <translation>Unngå lukking av vinduet ved feiltagelser (f.eks. ved dobbeltklikking av vinduet)</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="53"/>
+        <location filename="../aboutdialog.cpp" line="55"/>
         <source>Version: %1</source>
         <translation>Versjon: %1</translation>
     </message>
@@ -48,129 +48,129 @@
         <translation type="vanished">Opphavsrett © 2020 %1</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="64"/>
+        <location filename="../aboutdialog.cpp" line="66"/>
         <source>Logo designed by %1</source>
         <translation>Logo designet av %1</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="66"/>
+        <location filename="../aboutdialog.cpp" line="68"/>
         <source>Built with Qt %1 (%2)</source>
         <translation>Bygd med Qt %1 (%2)</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="67"/>
+        <location filename="../aboutdialog.cpp" line="69"/>
         <source>Source code</source>
         <translation>Kildekode</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="77"/>
+        <location filename="../aboutdialog.cpp" line="79"/>
         <source>Contributors</source>
         <translation>Bidragsytere</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="79"/>
+        <location filename="../aboutdialog.cpp" line="81"/>
         <source>List of contributors on GitHub</source>
         <translation>Liste over bidragsytere på GitHub</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="80"/>
+        <location filename="../aboutdialog.cpp" line="82"/>
         <source>Thanks to all people who contributed to this project.</source>
         <translation>Takk til alle som har bidratt til prosjektet.</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="84"/>
+        <location filename="../aboutdialog.cpp" line="86"/>
         <source>Translators</source>
         <translation>Oversettere</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="85"/>
+        <location filename="../aboutdialog.cpp" line="87"/>
         <source>I would like to thank the following people who volunteered to translate this application.</source>
         <translation>Takk til følgende dugnadsoversettere.</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="129"/>
+        <location filename="../aboutdialog.cpp" line="131"/>
         <source>%1 is built on the following free software libraries:</source>
         <comment>Free as in freedom</comment>
         <translation type="unfinished">%1 er bygd med følgende friprog-bibliotek:</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="153"/>
+        <location filename="../aboutdialog.cpp" line="155"/>
         <source>&amp;Special Thanks</source>
         <translation>&amp;Spesiell takk til</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="155"/>
+        <location filename="../aboutdialog.cpp" line="157"/>
         <source>&amp;Third-party Libraries</source>
         <translation>&amp;Tredjepartslisenser</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="91"/>
+        <location filename="../aboutdialog.cpp" line="93"/>
         <source>Your Rights</source>
         <translation>Dine rettigheter</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="46"/>
+        <location filename="../aboutdialog.cpp" line="48"/>
         <source>Avoid resetting the zoom/rotation/flip state that was applied to the image view when switching between images.</source>
         <translation>Unngå å tilbakestille tilstanden for zoom/rotasjon/speilvending som ble brukt på bildevisningen, når det skiftes mellom bilder.</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="61"/>
+        <location filename="../aboutdialog.cpp" line="63"/>
         <source>Copyright (c) %1 %2</source>
         <comment>%1 is year, %2 is the name of copyright holder(s)</comment>
         <translation type="unfinished">Opphavsrett © %1 %2</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="93"/>
+        <location filename="../aboutdialog.cpp" line="95"/>
         <source>%1 is released under the MIT License.</source>
         <translation>%1 er MIT-lisensiert.</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="94"/>
+        <location filename="../aboutdialog.cpp" line="96"/>
         <source>This license grants people a number of freedoms:</source>
         <translation>Lisensen gir den en rekke friheter:</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="95"/>
+        <location filename="../aboutdialog.cpp" line="97"/>
         <source>You are free to use %1, for any purpose</source>
         <translation>Du kan bruke %1 som du vil</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="96"/>
+        <location filename="../aboutdialog.cpp" line="98"/>
         <source>You are free to distribute %1</source>
         <translation>Du kan dele %1</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="97"/>
+        <location filename="../aboutdialog.cpp" line="99"/>
         <source>You can study how %1 works and change it</source>
         <translation>Du kan se kildekoden til %1 og endre den</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="98"/>
+        <location filename="../aboutdialog.cpp" line="100"/>
         <source>You can distribute changed versions of %1</source>
         <translation>Du kan distribuere endrede versjoner av %1</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="100"/>
+        <location filename="../aboutdialog.cpp" line="102"/>
         <source>The MIT license guarantees you this freedom. Nobody is ever permitted to take it away.</source>
         <translation>MIT-lisensen garanterer deg disse frihetene.</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="128"/>
+        <location filename="../aboutdialog.cpp" line="130"/>
         <source>Third-party Libraries used by %1</source>
         <translation>Tredjepartsbibliotek brukt av %1</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="151"/>
+        <location filename="../aboutdialog.cpp" line="153"/>
         <source>&amp;Help</source>
         <translation>&amp;Hjelp</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="152"/>
+        <location filename="../aboutdialog.cpp" line="154"/>
         <source>&amp;About</source>
         <translation>&amp;Om</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="154"/>
+        <location filename="../aboutdialog.cpp" line="156"/>
         <source>&amp;License</source>
         <translation>&amp;Lisens</translation>
     </message>
@@ -178,7 +178,7 @@
 <context>
     <name>GraphicsScene</name>
     <message>
-        <location filename="../mainwindow.cpp" line="272"/>
+        <location filename="../mainwindow.cpp" line="276"/>
         <location filename="../graphicsscene.cpp" line="100"/>
         <source>Drag image here</source>
         <translation>Dra bilde hit</translation>
@@ -191,13 +191,13 @@
         <translation type="vanished">Listen over filnettadresser er tom</translation>
     </message>
     <message>
-        <location filename="../graphicsview.cpp" line="52"/>
+        <location filename="../graphicsview.cpp" line="50"/>
         <source>File is not a valid image</source>
         <translation>Filen er ikke et gyldig bilde</translation>
     </message>
     <message>
-        <location filename="../graphicsview.cpp" line="56"/>
-        <location filename="../graphicsview.cpp" line="60"/>
+        <location filename="../graphicsview.cpp" line="54"/>
+        <location filename="../graphicsview.cpp" line="58"/>
         <source>Image data is invalid or currently unsupported</source>
         <translation>Ugyldig bildedata, eller for tiden ustøttet</translation>
     </message>
@@ -213,38 +213,43 @@
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../mainwindow.cpp" line="180"/>
-        <location filename="../mainwindow.cpp" line="543"/>
+        <location filename="../mainwindow.cpp" line="181"/>
+        <location filename="../mainwindow.cpp" line="545"/>
         <source>File url list is empty</source>
         <translation>Listen over filnettadresser er ugyldig</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="441"/>
+        <location filename="../mainwindow.cpp" line="445"/>
         <source>&amp;Copy</source>
         <translation>&amp;Kopier</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="551"/>
+        <location filename="../mainwindow.cpp" line="553"/>
         <source>Image data is invalid</source>
         <translation>Ugyldig bildedata</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="558"/>
+        <location filename="../mainwindow.cpp" line="560"/>
         <source>Not supported mimedata: %1</source>
         <translation>Ustøttet MIME-data: %1</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="754"/>
+        <location filename="../mainwindow.cpp" line="759"/>
         <source>Image From Clipboard</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="772"/>
+        <location filename="../mainwindow.cpp" line="777"/>
         <source>Are you sure you want to move &quot;%1&quot; to recycle bin?</source>
         <translation>Er du sikker på at du vil flytte &quot;%1&quot; til papirkurven?</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="777"/>
+        <location filename="../mainwindow.cpp" line="781"/>
+        <source>Failed to move file to trash</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="782"/>
         <source>Move to trash failed, it might caused by file permission issue, file system limitation, or platform limitation.</source>
         <translation>Flytt til papirkurven mislyktes, det kan skyldes filtillatelsesproblem, filsystembegrensning eller plattformbegrensning.</translation>
     </message>
@@ -265,19 +270,19 @@
     </message>
     <message>
         <location filename="../actionmanager.cpp" line="118"/>
-        <location filename="../aboutdialog.cpp" line="39"/>
+        <location filename="../aboutdialog.cpp" line="41"/>
         <source>Stay on top</source>
         <translation>Behold øverst</translation>
     </message>
     <message>
         <location filename="../actionmanager.cpp" line="119"/>
-        <location filename="../aboutdialog.cpp" line="42"/>
+        <location filename="../aboutdialog.cpp" line="44"/>
         <source>Protected mode</source>
         <translation>Beskyttet modus</translation>
     </message>
     <message>
         <location filename="../actionmanager.cpp" line="120"/>
-        <location filename="../aboutdialog.cpp" line="45"/>
+        <location filename="../aboutdialog.cpp" line="47"/>
         <source>Keep transformation</source>
         <comment>The &apos;transformation&apos; means the flip/rotation status that currently applied to the image view</comment>
         <translation>Behold transformasjon</translation>
@@ -363,7 +368,7 @@
         <translation>Neste bilde</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="771"/>
+        <location filename="../mainwindow.cpp" line="776"/>
         <location filename="../actionmanager.cpp" line="117"/>
         <source>Move to Trash</source>
         <translation>Flytt til papirkurven</translation>
@@ -406,314 +411,314 @@
 <context>
     <name>MetadataModel</name>
     <message>
-        <location filename="../metadatamodel.cpp" line="41"/>
+        <location filename="../metadatamodel.cpp" line="43"/>
         <source>Origin</source>
         <comment>Section name.</comment>
         <translation>Opprinnelse</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="42"/>
+        <location filename="../metadatamodel.cpp" line="44"/>
         <source>Image</source>
         <comment>Section name.</comment>
         <translation>Bilde</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="46"/>
+        <location filename="../metadatamodel.cpp" line="48"/>
         <source>File</source>
         <comment>Section name.</comment>
         <translation>Fil</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="43"/>
+        <location filename="../metadatamodel.cpp" line="45"/>
         <source>Camera</source>
         <comment>Section name.</comment>
         <translation>Kamera</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="33"/>
+        <location filename="../metadatamodel.cpp" line="35"/>
         <source>%1 File</source>
         <translation>%1-fil</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="40"/>
+        <location filename="../metadatamodel.cpp" line="42"/>
         <source>Description</source>
         <comment>Section name.</comment>
         <translation>Beskrivelse</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="44"/>
+        <location filename="../metadatamodel.cpp" line="46"/>
         <source>Advanced photo</source>
         <comment>Section name.</comment>
         <translation>Avansert bilde</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="45"/>
+        <location filename="../metadatamodel.cpp" line="47"/>
         <source>GPS</source>
         <comment>Section name.</comment>
         <translation>GPS</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="50"/>
+        <location filename="../metadatamodel.cpp" line="52"/>
         <source>Dimensions</source>
         <translation>Dimensjoner</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="52"/>
+        <location filename="../metadatamodel.cpp" line="54"/>
         <source>Aspect ratio</source>
         <translation>Sideforhold</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="56"/>
+        <location filename="../metadatamodel.cpp" line="58"/>
         <source>Frame count</source>
         <translation type="unfinished">Rammeantall</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="60"/>
+        <location filename="../metadatamodel.cpp" line="62"/>
         <source>Name</source>
         <translation>Navn</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="62"/>
+        <location filename="../metadatamodel.cpp" line="64"/>
         <source>Item type</source>
         <translation>Elementstype</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="64"/>
+        <location filename="../metadatamodel.cpp" line="66"/>
         <source>Folder path</source>
         <translation>Mappesti</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="66"/>
+        <location filename="../metadatamodel.cpp" line="68"/>
         <source>Size</source>
         <translation>Størrelse</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="68"/>
+        <location filename="../metadatamodel.cpp" line="70"/>
         <source>Date created</source>
         <translation>Dato opprettet</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="70"/>
+        <location filename="../metadatamodel.cpp" line="72"/>
         <source>Date modified</source>
         <translation>Dato endret</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="77"/>
+        <location filename="../metadatamodel.cpp" line="79"/>
         <source>Title</source>
         <translation>Tittel</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="79"/>
+        <location filename="../metadatamodel.cpp" line="81"/>
         <source>Subject</source>
         <translation>Emne</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="81"/>
+        <location filename="../metadatamodel.cpp" line="83"/>
         <source>Rating</source>
         <translation>Vurdering</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="83"/>
+        <location filename="../metadatamodel.cpp" line="85"/>
         <source>Tags</source>
         <translation>Etiketter</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="85"/>
+        <location filename="../metadatamodel.cpp" line="87"/>
         <source>Comments</source>
         <translation>Kommentarer</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="88"/>
+        <location filename="../metadatamodel.cpp" line="90"/>
         <source>Authors</source>
         <translation>Utviklere</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="90"/>
+        <location filename="../metadatamodel.cpp" line="92"/>
         <source>Date taken</source>
         <translation>Dato tatt</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="96"/>
+        <location filename="../metadatamodel.cpp" line="98"/>
         <source>Program name</source>
         <translation>Programnavn</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="98"/>
+        <location filename="../metadatamodel.cpp" line="100"/>
         <source>Copyright</source>
         <translation>Opphavsrett</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="101"/>
+        <location filename="../metadatamodel.cpp" line="103"/>
         <source>Horizontal resolution</source>
         <translation>Vannrett oppløsning</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="103"/>
+        <location filename="../metadatamodel.cpp" line="105"/>
         <source>Vertical resolution</source>
         <translation>Loddrett oppløsning</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="105"/>
+        <location filename="../metadatamodel.cpp" line="107"/>
         <source>Resolution unit</source>
         <translation>Oppløsningsenhet</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="107"/>
+        <location filename="../metadatamodel.cpp" line="109"/>
         <source>Colour representation</source>
         <translation>Fargerepresentasjon</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="110"/>
+        <location filename="../metadatamodel.cpp" line="112"/>
         <source>Camera maker</source>
         <translation>Kamerafabrikat</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="112"/>
+        <location filename="../metadatamodel.cpp" line="114"/>
         <source>Camera model</source>
         <translation>Kameramodell</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="114"/>
+        <location filename="../metadatamodel.cpp" line="116"/>
         <source>F-stop</source>
         <translation>Blenderåpning</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="116"/>
+        <location filename="../metadatamodel.cpp" line="118"/>
         <source>Exposure time</source>
         <translation>Eksponeringstid</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="118"/>
+        <location filename="../metadatamodel.cpp" line="120"/>
         <source>ISO speed</source>
         <translation>ISO-hastighet</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="120"/>
+        <location filename="../metadatamodel.cpp" line="122"/>
         <source>Exposure bias</source>
         <translation type="unfinished">Eksponeringskorrigering</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="122"/>
+        <location filename="../metadatamodel.cpp" line="124"/>
         <source>Focal length</source>
         <translation>Brennvidde</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="124"/>
+        <location filename="../metadatamodel.cpp" line="126"/>
         <source>Max aperture</source>
         <translation type="unfinished">Maks. blenderåpning</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="126"/>
+        <location filename="../metadatamodel.cpp" line="128"/>
         <source>Metering mode</source>
         <translation type="unfinished">Målingsmodus</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="128"/>
+        <location filename="../metadatamodel.cpp" line="130"/>
         <source>Subject distance</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="130"/>
+        <location filename="../metadatamodel.cpp" line="132"/>
         <source>Flash mode</source>
         <translation>Blitz-modus</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="132"/>
+        <location filename="../metadatamodel.cpp" line="134"/>
         <source>35mm focal length</source>
         <translation type="unfinished">35 mm-brennvidde</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="135"/>
+        <location filename="../metadatamodel.cpp" line="137"/>
         <source>Lens model</source>
         <translation>Linsemodell</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="137"/>
+        <location filename="../metadatamodel.cpp" line="139"/>
         <source>Contrast</source>
         <translation>Kontrast</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="139"/>
+        <location filename="../metadatamodel.cpp" line="141"/>
         <source>Brightness</source>
         <translation>Lysstyrke</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="141"/>
+        <location filename="../metadatamodel.cpp" line="143"/>
         <source>Exposure program</source>
         <translation type="unfinished">Eksponeringsprogram</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="143"/>
+        <location filename="../metadatamodel.cpp" line="145"/>
         <source>Saturation</source>
         <translation>Metning</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="145"/>
+        <location filename="../metadatamodel.cpp" line="147"/>
         <source>Sharpness</source>
         <translation>Skarphet</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="147"/>
+        <location filename="../metadatamodel.cpp" line="149"/>
         <source>White balance</source>
         <translation>Hvitbalanse</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="149"/>
+        <location filename="../metadatamodel.cpp" line="151"/>
         <source>Digital zoom</source>
         <translation>Digital forstørrelse</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="151"/>
+        <location filename="../metadatamodel.cpp" line="153"/>
         <source>EXIF version</source>
         <translation>EXIF-versjon</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="154"/>
+        <location filename="../metadatamodel.cpp" line="156"/>
         <source>Latitude reference</source>
         <translation>Breddegradsreferanse</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="156"/>
+        <location filename="../metadatamodel.cpp" line="158"/>
         <source>Latitude</source>
         <translation>Breddegrad</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="158"/>
+        <location filename="../metadatamodel.cpp" line="160"/>
         <source>Longitude reference</source>
         <translation>Lengdegradsreferanse</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="160"/>
+        <location filename="../metadatamodel.cpp" line="162"/>
         <source>Longitude</source>
         <translation>Lengdegrad</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="162"/>
+        <location filename="../metadatamodel.cpp" line="164"/>
         <source>Altitude reference</source>
         <translation>Høydereferanse</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="164"/>
+        <location filename="../metadatamodel.cpp" line="166"/>
         <source>Altitude</source>
         <translation>Høyde</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="174"/>
+        <location filename="../metadatamodel.cpp" line="176"/>
         <source>%1 x %2</source>
         <translation>%1 x %2</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="192"/>
+        <location filename="../metadatamodel.cpp" line="194"/>
         <source>%1 : %2</source>
         <translation>%1 : %2</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="317"/>
+        <location filename="../metadatamodel.cpp" line="319"/>
         <source>Property</source>
         <translation>Egenskap</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="317"/>
+        <location filename="../metadatamodel.cpp" line="319"/>
         <source>Value</source>
         <translation>Verdi</translation>
     </message>
@@ -721,131 +726,141 @@
 <context>
     <name>SettingsDialog</name>
     <message>
-        <location filename="../settingsdialog.cpp" line="29"/>
+        <location filename="../settingsdialog.cpp" line="31"/>
         <source>Settings</source>
         <translation>Innstillinger</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="37"/>
+        <location filename="../settingsdialog.cpp" line="39"/>
         <source>Options</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="49"/>
+        <location filename="../settingsdialog.cpp" line="51"/>
         <source>Shortcuts</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="59"/>
+        <location filename="../settingsdialog.cpp" line="61"/>
         <source>Editing shortcuts for action &quot;%1&quot;:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="68"/>
+        <location filename="../settingsdialog.cpp" line="70"/>
         <source>Failed to set shortcuts</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="69"/>
+        <location filename="../settingsdialog.cpp" line="71"/>
         <source>Please check if shortcuts are duplicated with existing shortcuts.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="76"/>
+        <location filename="../settingsdialog.cpp" line="78"/>
         <source>Do nothing</source>
         <translation>Ikke gjør noe</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="77"/>
+        <location filename="../settingsdialog.cpp" line="79"/>
         <source>Close the window</source>
         <translation>Lukk vinduet</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="78"/>
+        <location filename="../settingsdialog.cpp" line="80"/>
         <source>Toggle maximize</source>
         <translation>Maksimering av/på</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="79"/>
+        <location filename="../settingsdialog.cpp" line="81"/>
         <source>Toggle fullscreen</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="83"/>
+        <location filename="../settingsdialog.cpp" line="85"/>
         <source>Zoom in and out</source>
         <translation>Zoom inn og ut</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="84"/>
+        <location filename="../settingsdialog.cpp" line="86"/>
         <source>View next or previous item</source>
         <translation>Vis neste eller forrige element</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="88"/>
+        <location filename="../settingsdialog.cpp" line="90"/>
         <source>Auto size</source>
         <translation type="unfinished">Automatisk størrelse</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="89"/>
+        <location filename="../settingsdialog.cpp" line="91"/>
         <source>Maximized</source>
         <translation>Maksimert</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="90"/>
+        <location filename="../settingsdialog.cpp" line="92"/>
         <source>Windowed</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="94"/>
+        <location filename="../settingsdialog.cpp" line="96"/>
         <source>Round (Integer scaling)</source>
         <comment>This option means round up for .5 and above</comment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="95"/>
+        <location filename="../settingsdialog.cpp" line="97"/>
         <source>Ceil (Integer scaling)</source>
         <comment>This option means always round up</comment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="96"/>
+        <location filename="../settingsdialog.cpp" line="98"/>
         <source>Floor (Integer scaling)</source>
         <comment>This option means always round down</comment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="97"/>
+        <location filename="../settingsdialog.cpp" line="99"/>
         <source>Follow system (Fractional scaling)</source>
         <comment>This option means don&apos;t round</comment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="120"/>
+        <location filename="../settingsdialog.cpp" line="122"/>
         <source>Stay on top when start-up</source>
         <translation>Behold i forgrunnen ved oppstart</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="121"/>
+        <location filename="../settingsdialog.cpp" line="123"/>
+        <source>Use built-in close window animation</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.cpp" line="124"/>
         <source>Use light-color checkerboard</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="122"/>
+        <location filename="../settingsdialog.cpp" line="125"/>
+        <source>Loop the loaded gallery</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.cpp" line="126"/>
         <source>Double-click behavior</source>
         <translation>Dobbeltklikksoppførsel</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="123"/>
+        <location filename="../settingsdialog.cpp" line="127"/>
         <source>Mouse wheel behavior</source>
         <translation>Musehjulsoppførsel</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="124"/>
+        <location filename="../settingsdialog.cpp" line="128"/>
         <source>Default window size</source>
         <translation>Forvalgt vindusstørrelse</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="125"/>
+        <location filename="../settingsdialog.cpp" line="129"/>
         <source>HiDPI scale factor rounding policy</source>
         <translation type="unfinished"></translation>
     </message>
@@ -853,7 +868,7 @@
 <context>
     <name>ShortcutEdit</name>
     <message>
-        <location filename="../shortcutedit.cpp" line="111"/>
+        <location filename="../shortcutedit.cpp" line="109"/>
         <source>No shortcuts</source>
         <translation type="unfinished"></translation>
     </message>
@@ -861,7 +876,7 @@
 <context>
     <name>ShortcutEditor</name>
     <message>
-        <location filename="../shortcutedit.cpp" line="77"/>
+        <location filename="../shortcutedit.cpp" line="75"/>
         <source>Shortcut #%1</source>
         <translation type="unfinished"></translation>
     </message>
@@ -869,17 +884,17 @@
 <context>
     <name>main</name>
     <message>
-        <location filename="../main.cpp" line="43"/>
+        <location filename="../main.cpp" line="42"/>
         <source>Pineapple Pictures</source>
         <translation>Pineapple Pictures</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="46"/>
+        <location filename="../main.cpp" line="45"/>
         <source>List supported image format suffixes, and quit program.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="50"/>
+        <location filename="../main.cpp" line="49"/>
         <source>File list.</source>
         <translation>Filliste.</translation>
     </message>
