@@ -4,169 +4,169 @@
 <context>
     <name>AboutDialog</name>
     <message>
-        <location filename="../aboutdialog.cpp" line="27"/>
+        <location filename="../aboutdialog.cpp" line="29"/>
         <source>About</source>
         <translation>Про додаток</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="30"/>
+        <location filename="../aboutdialog.cpp" line="32"/>
         <source>Launch application with image file path as argument to load the file.</source>
         <translation>Запустіть додаток, вказавши шлях до файлу зображення у якості аргументу для завантаження файлу.</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="31"/>
+        <location filename="../aboutdialog.cpp" line="33"/>
         <source>Drag and drop image file onto the window is also supported.</source>
         <translation>Також підтримується перетягування файлу зображення у вікно.</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="32"/>
+        <location filename="../aboutdialog.cpp" line="34"/>
         <source>None of the operations in this application will alter the pictures on disk.</source>
         <translation>Жодна з операцій у цьому додатку не змінить зображення на диску.</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="33"/>
+        <location filename="../aboutdialog.cpp" line="35"/>
         <source>Context menu option explanation:</source>
         <translation>Пояснення пунктів контекстного меню:</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="40"/>
+        <location filename="../aboutdialog.cpp" line="42"/>
         <source>Make window stay on top of all other windows.</source>
         <translation>Зробити так, щоб вікно залишалося поверх усіх інших вікон.</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="43"/>
+        <location filename="../aboutdialog.cpp" line="45"/>
         <source>Avoid close window accidentally. (eg. by double clicking the window)</source>
         <translation>Уникати випадкового закривання вікна. (Наприклад, подвійним клацанням по вікну.)</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="46"/>
+        <location filename="../aboutdialog.cpp" line="48"/>
         <source>Avoid resetting the zoom/rotation/flip state that was applied to the image view when switching between images.</source>
         <translation>Уникати скидання стану масштабування/обертання/гортання яке було застосовано до перегляду зображення при перемиканні зображень.</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="53"/>
+        <location filename="../aboutdialog.cpp" line="55"/>
         <source>Version: %1</source>
         <translation>Версія: %1</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="64"/>
+        <location filename="../aboutdialog.cpp" line="66"/>
         <source>Logo designed by %1</source>
         <translation>Логотип розроблено %1</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="66"/>
+        <location filename="../aboutdialog.cpp" line="68"/>
         <source>Built with Qt %1 (%2)</source>
         <translation>Побудований за допомогою Qt %1 (%2)</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="67"/>
+        <location filename="../aboutdialog.cpp" line="69"/>
         <source>Source code</source>
         <translation>Джерельний код</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="77"/>
+        <location filename="../aboutdialog.cpp" line="79"/>
         <source>Contributors</source>
         <translation>Учасники</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="79"/>
+        <location filename="../aboutdialog.cpp" line="81"/>
         <source>List of contributors on GitHub</source>
         <translation>Список учасників на GitHub</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="80"/>
+        <location filename="../aboutdialog.cpp" line="82"/>
         <source>Thanks to all people who contributed to this project.</source>
         <translation>Дякуємо всім, хто долучився до цього проєкту.</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="84"/>
+        <location filename="../aboutdialog.cpp" line="86"/>
         <source>Translators</source>
         <translation>Перекладачі</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="85"/>
+        <location filename="../aboutdialog.cpp" line="87"/>
         <source>I would like to thank the following people who volunteered to translate this application.</source>
         <translation>Я хотів би подякувати наступним людям, які прийняли участь у перекладі цього додатку.</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="129"/>
+        <location filename="../aboutdialog.cpp" line="131"/>
         <source>%1 is built on the following free software libraries:</source>
         <comment>Free as in freedom</comment>
         <translation>%1 побудовано на наступних вільних бібліотеках:</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="153"/>
+        <location filename="../aboutdialog.cpp" line="155"/>
         <source>&amp;Special Thanks</source>
         <translation>&amp;Особлива подяка</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="155"/>
+        <location filename="../aboutdialog.cpp" line="157"/>
         <source>&amp;Third-party Libraries</source>
         <translation>&amp;Сторонні бібліотеки</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="91"/>
+        <location filename="../aboutdialog.cpp" line="93"/>
         <source>Your Rights</source>
         <translation>Ваші права</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="61"/>
+        <location filename="../aboutdialog.cpp" line="63"/>
         <source>Copyright (c) %1 %2</source>
         <comment>%1 is year, %2 is the name of copyright holder(s)</comment>
         <translation>Авторське право (c) %1 %2</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="93"/>
+        <location filename="../aboutdialog.cpp" line="95"/>
         <source>%1 is released under the MIT License.</source>
         <translation>%1 випускається за ліцензією MIT.</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="94"/>
+        <location filename="../aboutdialog.cpp" line="96"/>
         <source>This license grants people a number of freedoms:</source>
         <translation>Ця ліцензія надає людям низку свобод:</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="95"/>
+        <location filename="../aboutdialog.cpp" line="97"/>
         <source>You are free to use %1, for any purpose</source>
         <translation>Ви можете вільно використовувати %1 для будь-яких цілей</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="96"/>
+        <location filename="../aboutdialog.cpp" line="98"/>
         <source>You are free to distribute %1</source>
         <translation>Ви можете вільно розповсюджувати %1</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="97"/>
+        <location filename="../aboutdialog.cpp" line="99"/>
         <source>You can study how %1 works and change it</source>
         <translation>Ви можете вивчити, як працює %1, і змінити його</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="98"/>
+        <location filename="../aboutdialog.cpp" line="100"/>
         <source>You can distribute changed versions of %1</source>
         <translation>Ви можете розповсюджувати змінені версії %1</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="100"/>
+        <location filename="../aboutdialog.cpp" line="102"/>
         <source>The MIT license guarantees you this freedom. Nobody is ever permitted to take it away.</source>
         <translation>Ліцензія MIT гарантує вам цю свободу. Ніхто не має права її відбирати.</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="128"/>
+        <location filename="../aboutdialog.cpp" line="130"/>
         <source>Third-party Libraries used by %1</source>
         <translation>Сторонні бібліотеки, що використовуються %1</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="151"/>
+        <location filename="../aboutdialog.cpp" line="153"/>
         <source>&amp;Help</source>
         <translation>&amp;Допомога</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="152"/>
+        <location filename="../aboutdialog.cpp" line="154"/>
         <source>&amp;About</source>
         <translation>&amp;Про додаток</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="154"/>
+        <location filename="../aboutdialog.cpp" line="156"/>
         <source>&amp;License</source>
         <translation>&amp;Ліцензія</translation>
     </message>
@@ -174,7 +174,7 @@
 <context>
     <name>GraphicsScene</name>
     <message>
-        <location filename="../mainwindow.cpp" line="272"/>
+        <location filename="../mainwindow.cpp" line="276"/>
         <location filename="../graphicsscene.cpp" line="100"/>
         <source>Drag image here</source>
         <translation>Перетягніть зображення сюди</translation>
@@ -187,13 +187,13 @@
         <translation type="vanished">Список URL-адрес файлів порожній</translation>
     </message>
     <message>
-        <location filename="../graphicsview.cpp" line="52"/>
+        <location filename="../graphicsview.cpp" line="50"/>
         <source>File is not a valid image</source>
         <translation>Файл не є дійсним зображенням</translation>
     </message>
     <message>
-        <location filename="../graphicsview.cpp" line="56"/>
-        <location filename="../graphicsview.cpp" line="60"/>
+        <location filename="../graphicsview.cpp" line="54"/>
+        <location filename="../graphicsview.cpp" line="58"/>
         <source>Image data is invalid or currently unsupported</source>
         <translation>Дані зображення недійсні або наразі не підтримуються</translation>
     </message>
@@ -209,38 +209,43 @@
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../mainwindow.cpp" line="180"/>
-        <location filename="../mainwindow.cpp" line="543"/>
+        <location filename="../mainwindow.cpp" line="181"/>
+        <location filename="../mainwindow.cpp" line="545"/>
         <source>File url list is empty</source>
         <translation>Список URL-адрес файлів порожній</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="441"/>
+        <location filename="../mainwindow.cpp" line="445"/>
         <source>&amp;Copy</source>
         <translation>&amp;Скопіювати</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="551"/>
+        <location filename="../mainwindow.cpp" line="553"/>
         <source>Image data is invalid</source>
         <translation>Дані зображення недійсні</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="558"/>
+        <location filename="../mainwindow.cpp" line="560"/>
         <source>Not supported mimedata: %1</source>
         <translation>Не підтримується mimedata: %1</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="754"/>
+        <location filename="../mainwindow.cpp" line="759"/>
         <source>Image From Clipboard</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="772"/>
+        <location filename="../mainwindow.cpp" line="777"/>
         <source>Are you sure you want to move &quot;%1&quot; to recycle bin?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="777"/>
+        <location filename="../mainwindow.cpp" line="781"/>
+        <source>Failed to move file to trash</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="782"/>
         <source>Move to trash failed, it might caused by file permission issue, file system limitation, or platform limitation.</source>
         <translation type="unfinished"></translation>
     </message>
@@ -261,19 +266,19 @@
     </message>
     <message>
         <location filename="../actionmanager.cpp" line="118"/>
-        <location filename="../aboutdialog.cpp" line="39"/>
+        <location filename="../aboutdialog.cpp" line="41"/>
         <source>Stay on top</source>
         <translation>Поверх всіх вікон</translation>
     </message>
     <message>
         <location filename="../actionmanager.cpp" line="119"/>
-        <location filename="../aboutdialog.cpp" line="42"/>
+        <location filename="../aboutdialog.cpp" line="44"/>
         <source>Protected mode</source>
         <translation>Захищений режим</translation>
     </message>
     <message>
         <location filename="../actionmanager.cpp" line="120"/>
-        <location filename="../aboutdialog.cpp" line="45"/>
+        <location filename="../aboutdialog.cpp" line="47"/>
         <source>Keep transformation</source>
         <comment>The &apos;transformation&apos; means the flip/rotation status that currently applied to the image view</comment>
         <translation>Зберігати трансформацію</translation>
@@ -359,7 +364,7 @@
         <translation>Наступне зображення</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="771"/>
+        <location filename="../mainwindow.cpp" line="776"/>
         <location filename="../actionmanager.cpp" line="117"/>
         <source>Move to Trash</source>
         <translation type="unfinished"></translation>
@@ -402,314 +407,314 @@
 <context>
     <name>MetadataModel</name>
     <message>
-        <location filename="../metadatamodel.cpp" line="41"/>
+        <location filename="../metadatamodel.cpp" line="43"/>
         <source>Origin</source>
         <comment>Section name.</comment>
         <translation>Походження</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="42"/>
+        <location filename="../metadatamodel.cpp" line="44"/>
         <source>Image</source>
         <comment>Section name.</comment>
         <translation>Зображення</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="46"/>
+        <location filename="../metadatamodel.cpp" line="48"/>
         <source>File</source>
         <comment>Section name.</comment>
         <translation>Файл</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="43"/>
+        <location filename="../metadatamodel.cpp" line="45"/>
         <source>Camera</source>
         <comment>Section name.</comment>
         <translation>Камера</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="33"/>
+        <location filename="../metadatamodel.cpp" line="35"/>
         <source>%1 File</source>
         <translation>%1 файл</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="40"/>
+        <location filename="../metadatamodel.cpp" line="42"/>
         <source>Description</source>
         <comment>Section name.</comment>
         <translation>Опис</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="44"/>
+        <location filename="../metadatamodel.cpp" line="46"/>
         <source>Advanced photo</source>
         <comment>Section name.</comment>
         <translation>Розширене фото</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="45"/>
+        <location filename="../metadatamodel.cpp" line="47"/>
         <source>GPS</source>
         <comment>Section name.</comment>
         <translation>GPS</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="50"/>
+        <location filename="../metadatamodel.cpp" line="52"/>
         <source>Dimensions</source>
         <translation>Розміри</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="52"/>
+        <location filename="../metadatamodel.cpp" line="54"/>
         <source>Aspect ratio</source>
         <translation>Співвідношення сторін</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="56"/>
+        <location filename="../metadatamodel.cpp" line="58"/>
         <source>Frame count</source>
         <translation>Кількість кадрів</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="60"/>
+        <location filename="../metadatamodel.cpp" line="62"/>
         <source>Name</source>
         <translation>Ім’я</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="62"/>
+        <location filename="../metadatamodel.cpp" line="64"/>
         <source>Item type</source>
         <translation>Тип елемента</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="64"/>
+        <location filename="../metadatamodel.cpp" line="66"/>
         <source>Folder path</source>
         <translation>Шлях до теки</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="66"/>
+        <location filename="../metadatamodel.cpp" line="68"/>
         <source>Size</source>
         <translation>Розмір</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="68"/>
+        <location filename="../metadatamodel.cpp" line="70"/>
         <source>Date created</source>
         <translation>Дата створення</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="70"/>
+        <location filename="../metadatamodel.cpp" line="72"/>
         <source>Date modified</source>
         <translation>Дата зміни</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="77"/>
+        <location filename="../metadatamodel.cpp" line="79"/>
         <source>Title</source>
         <translation>Назва</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="79"/>
+        <location filename="../metadatamodel.cpp" line="81"/>
         <source>Subject</source>
         <translation>Тема</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="81"/>
+        <location filename="../metadatamodel.cpp" line="83"/>
         <source>Rating</source>
         <translation>Рейтинг</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="83"/>
+        <location filename="../metadatamodel.cpp" line="85"/>
         <source>Tags</source>
         <translation>Мітки</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="85"/>
+        <location filename="../metadatamodel.cpp" line="87"/>
         <source>Comments</source>
         <translation>Коментарі</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="88"/>
+        <location filename="../metadatamodel.cpp" line="90"/>
         <source>Authors</source>
         <translation>Автори</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="90"/>
+        <location filename="../metadatamodel.cpp" line="92"/>
         <source>Date taken</source>
         <translation>Дата зйомки</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="96"/>
+        <location filename="../metadatamodel.cpp" line="98"/>
         <source>Program name</source>
         <translation>Назва програми</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="98"/>
+        <location filename="../metadatamodel.cpp" line="100"/>
         <source>Copyright</source>
         <translation>Авторське право</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="101"/>
+        <location filename="../metadatamodel.cpp" line="103"/>
         <source>Horizontal resolution</source>
         <translation>Роздільна здатність по горизонталі</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="103"/>
+        <location filename="../metadatamodel.cpp" line="105"/>
         <source>Vertical resolution</source>
         <translation>Роздільна здатність по вертикалі</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="105"/>
+        <location filename="../metadatamodel.cpp" line="107"/>
         <source>Resolution unit</source>
         <translation>Одиниця роздільної здатності</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="107"/>
+        <location filename="../metadatamodel.cpp" line="109"/>
         <source>Colour representation</source>
         <translation>Представлення кольору</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="110"/>
+        <location filename="../metadatamodel.cpp" line="112"/>
         <source>Camera maker</source>
         <translation>Виробник камери</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="112"/>
+        <location filename="../metadatamodel.cpp" line="114"/>
         <source>Camera model</source>
         <translation>Модель камери</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="114"/>
+        <location filename="../metadatamodel.cpp" line="116"/>
         <source>F-stop</source>
         <translation>Діафрагма (F)</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="116"/>
+        <location filename="../metadatamodel.cpp" line="118"/>
         <source>Exposure time</source>
         <translation>Час експозиції</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="118"/>
+        <location filename="../metadatamodel.cpp" line="120"/>
         <source>ISO speed</source>
         <translation>Чутливість ISO</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="120"/>
+        <location filename="../metadatamodel.cpp" line="122"/>
         <source>Exposure bias</source>
         <translation>Зсув експозиції</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="122"/>
+        <location filename="../metadatamodel.cpp" line="124"/>
         <source>Focal length</source>
         <translation>Фокусна відстань</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="124"/>
+        <location filename="../metadatamodel.cpp" line="126"/>
         <source>Max aperture</source>
         <translation>Максимальна апертура</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="126"/>
+        <location filename="../metadatamodel.cpp" line="128"/>
         <source>Metering mode</source>
         <translation>Режим вимірювання</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="128"/>
+        <location filename="../metadatamodel.cpp" line="130"/>
         <source>Subject distance</source>
         <translation>Відстань до об&apos;єкта зйомки</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="130"/>
+        <location filename="../metadatamodel.cpp" line="132"/>
         <source>Flash mode</source>
         <translation>Режим спалаху</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="132"/>
+        <location filename="../metadatamodel.cpp" line="134"/>
         <source>35mm focal length</source>
         <translation>Фокусна відстань 35 мм</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="135"/>
+        <location filename="../metadatamodel.cpp" line="137"/>
         <source>Lens model</source>
         <translation>Модель об&apos;єктива</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="137"/>
+        <location filename="../metadatamodel.cpp" line="139"/>
         <source>Contrast</source>
         <translation>Контраст</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="139"/>
+        <location filename="../metadatamodel.cpp" line="141"/>
         <source>Brightness</source>
         <translation>Яскравість</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="141"/>
+        <location filename="../metadatamodel.cpp" line="143"/>
         <source>Exposure program</source>
         <translation>Програма експозиції</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="143"/>
+        <location filename="../metadatamodel.cpp" line="145"/>
         <source>Saturation</source>
         <translation>Насиченість</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="145"/>
+        <location filename="../metadatamodel.cpp" line="147"/>
         <source>Sharpness</source>
         <translation>Різкість</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="147"/>
+        <location filename="../metadatamodel.cpp" line="149"/>
         <source>White balance</source>
         <translation>Баланс білого</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="149"/>
+        <location filename="../metadatamodel.cpp" line="151"/>
         <source>Digital zoom</source>
         <translation>Цифровий зум</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="151"/>
+        <location filename="../metadatamodel.cpp" line="153"/>
         <source>EXIF version</source>
         <translation>Версія EXIF</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="154"/>
+        <location filename="../metadatamodel.cpp" line="156"/>
         <source>Latitude reference</source>
         <translation>Посилання на широту</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="156"/>
+        <location filename="../metadatamodel.cpp" line="158"/>
         <source>Latitude</source>
         <translation>Широта</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="158"/>
+        <location filename="../metadatamodel.cpp" line="160"/>
         <source>Longitude reference</source>
         <translation>Посилання на довготу</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="160"/>
+        <location filename="../metadatamodel.cpp" line="162"/>
         <source>Longitude</source>
         <translation>Довгота</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="162"/>
+        <location filename="../metadatamodel.cpp" line="164"/>
         <source>Altitude reference</source>
         <translation>Посилання на висоту над рівнем моря</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="164"/>
+        <location filename="../metadatamodel.cpp" line="166"/>
         <source>Altitude</source>
         <translation>Висота над рівнем моря</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="174"/>
+        <location filename="../metadatamodel.cpp" line="176"/>
         <source>%1 x %2</source>
         <translation>%1 x %2</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="192"/>
+        <location filename="../metadatamodel.cpp" line="194"/>
         <source>%1 : %2</source>
         <translation>%1 : %2</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="317"/>
+        <location filename="../metadatamodel.cpp" line="319"/>
         <source>Property</source>
         <translation>Власність</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="317"/>
+        <location filename="../metadatamodel.cpp" line="319"/>
         <source>Value</source>
         <translation>Значення</translation>
     </message>
@@ -717,131 +722,141 @@
 <context>
     <name>SettingsDialog</name>
     <message>
-        <location filename="../settingsdialog.cpp" line="29"/>
+        <location filename="../settingsdialog.cpp" line="31"/>
         <source>Settings</source>
         <translation>Налаштування</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="37"/>
+        <location filename="../settingsdialog.cpp" line="39"/>
         <source>Options</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="49"/>
+        <location filename="../settingsdialog.cpp" line="51"/>
         <source>Shortcuts</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="59"/>
+        <location filename="../settingsdialog.cpp" line="61"/>
         <source>Editing shortcuts for action &quot;%1&quot;:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="68"/>
+        <location filename="../settingsdialog.cpp" line="70"/>
         <source>Failed to set shortcuts</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="69"/>
+        <location filename="../settingsdialog.cpp" line="71"/>
         <source>Please check if shortcuts are duplicated with existing shortcuts.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="76"/>
+        <location filename="../settingsdialog.cpp" line="78"/>
         <source>Do nothing</source>
         <translation>Нічого не робити</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="77"/>
+        <location filename="../settingsdialog.cpp" line="79"/>
         <source>Close the window</source>
         <translation>Закрити вікно</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="78"/>
+        <location filename="../settingsdialog.cpp" line="80"/>
         <source>Toggle maximize</source>
         <translation>Перемкнути на максимум</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="79"/>
+        <location filename="../settingsdialog.cpp" line="81"/>
         <source>Toggle fullscreen</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="83"/>
+        <location filename="../settingsdialog.cpp" line="85"/>
         <source>Zoom in and out</source>
         <translation>Збільшення та зменшення</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="84"/>
+        <location filename="../settingsdialog.cpp" line="86"/>
         <source>View next or previous item</source>
         <translation>Переглянути наступний або попередній елемент</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="88"/>
+        <location filename="../settingsdialog.cpp" line="90"/>
         <source>Auto size</source>
         <translation>Автоматичний розмір</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="89"/>
+        <location filename="../settingsdialog.cpp" line="91"/>
         <source>Maximized</source>
         <translation>Максимізувати</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="90"/>
+        <location filename="../settingsdialog.cpp" line="92"/>
         <source>Windowed</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="94"/>
+        <location filename="../settingsdialog.cpp" line="96"/>
         <source>Round (Integer scaling)</source>
         <comment>This option means round up for .5 and above</comment>
         <translation>Round (цілочисельне масштабування)</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="95"/>
+        <location filename="../settingsdialog.cpp" line="97"/>
         <source>Ceil (Integer scaling)</source>
         <comment>This option means always round up</comment>
         <translation>Ceil (цілочисельне масштабування)</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="96"/>
+        <location filename="../settingsdialog.cpp" line="98"/>
         <source>Floor (Integer scaling)</source>
         <comment>This option means always round down</comment>
         <translation>Floor (цілочисельне масштабування)</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="97"/>
+        <location filename="../settingsdialog.cpp" line="99"/>
         <source>Follow system (Fractional scaling)</source>
         <comment>This option means don&apos;t round</comment>
         <translation>Стежити за системою (дробове масштабування)</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="120"/>
+        <location filename="../settingsdialog.cpp" line="122"/>
         <source>Stay on top when start-up</source>
         <translation>Поверх всіх вікон під час запуску</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="121"/>
+        <location filename="../settingsdialog.cpp" line="123"/>
+        <source>Use built-in close window animation</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.cpp" line="124"/>
         <source>Use light-color checkerboard</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="122"/>
+        <location filename="../settingsdialog.cpp" line="125"/>
+        <source>Loop the loaded gallery</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.cpp" line="126"/>
         <source>Double-click behavior</source>
         <translation>Поведінка при подвійному кліку</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="123"/>
+        <location filename="../settingsdialog.cpp" line="127"/>
         <source>Mouse wheel behavior</source>
         <translation>Поведінка колеса миші</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="124"/>
+        <location filename="../settingsdialog.cpp" line="128"/>
         <source>Default window size</source>
         <translation>Розмір вікна за замовчуванням</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="125"/>
+        <location filename="../settingsdialog.cpp" line="129"/>
         <source>HiDPI scale factor rounding policy</source>
         <translation>Політика округлення коефіцієнта HiDPI</translation>
     </message>
@@ -849,7 +864,7 @@
 <context>
     <name>ShortcutEdit</name>
     <message>
-        <location filename="../shortcutedit.cpp" line="111"/>
+        <location filename="../shortcutedit.cpp" line="109"/>
         <source>No shortcuts</source>
         <translation type="unfinished"></translation>
     </message>
@@ -857,7 +872,7 @@
 <context>
     <name>ShortcutEditor</name>
     <message>
-        <location filename="../shortcutedit.cpp" line="77"/>
+        <location filename="../shortcutedit.cpp" line="75"/>
         <source>Shortcut #%1</source>
         <translation type="unfinished"></translation>
     </message>
@@ -865,17 +880,17 @@
 <context>
     <name>main</name>
     <message>
-        <location filename="../main.cpp" line="43"/>
+        <location filename="../main.cpp" line="42"/>
         <source>Pineapple Pictures</source>
         <translation>Pineapple Pictures</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="46"/>
+        <location filename="../main.cpp" line="45"/>
         <source>List supported image format suffixes, and quit program.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="50"/>
+        <location filename="../main.cpp" line="49"/>
         <source>File list.</source>
         <translation>Список файлів.</translation>
     </message>
