@@ -4,42 +4,42 @@
 <context>
     <name>AboutDialog</name>
     <message>
-        <location filename="../aboutdialog.cpp" line="27"/>
+        <location filename="../aboutdialog.cpp" line="29"/>
         <source>About</source>
         <translation>关于</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="30"/>
+        <location filename="../aboutdialog.cpp" line="32"/>
         <source>Launch application with image file path as argument to load the file.</source>
         <translation>以图片文件的路径作为参数运行程序即可直接打开图片文件。</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="31"/>
+        <location filename="../aboutdialog.cpp" line="33"/>
         <source>Drag and drop image file onto the window is also supported.</source>
         <translation>也支持拖放图片文件到窗口内来加载图片。</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="32"/>
+        <location filename="../aboutdialog.cpp" line="34"/>
         <source>None of the operations in this application will alter the pictures on disk.</source>
         <translation>此程序中所有的操作均不会修改图片文件本身。</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="33"/>
+        <location filename="../aboutdialog.cpp" line="35"/>
         <source>Context menu option explanation:</source>
         <translation>菜单项说明：</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="40"/>
+        <location filename="../aboutdialog.cpp" line="42"/>
         <source>Make window stay on top of all other windows.</source>
         <translation>使窗口始终至于其它非置顶窗口上方。</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="43"/>
+        <location filename="../aboutdialog.cpp" line="45"/>
         <source>Avoid close window accidentally. (eg. by double clicking the window)</source>
         <translation>避免窗口意外关闭。（如：不小心双击了窗口触发了关闭窗口行为）</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="53"/>
+        <location filename="../aboutdialog.cpp" line="55"/>
         <source>Version: %1</source>
         <translation>版本: %1</translation>
     </message>
@@ -48,129 +48,129 @@
         <translation type="vanished">版权所有 (c) 2020 %1</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="64"/>
+        <location filename="../aboutdialog.cpp" line="66"/>
         <source>Logo designed by %1</source>
         <translation>Logo 由 %1 设计</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="66"/>
+        <location filename="../aboutdialog.cpp" line="68"/>
         <source>Built with Qt %1 (%2)</source>
         <translation>使用 Qt %1 (%2) 进行构建</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="67"/>
+        <location filename="../aboutdialog.cpp" line="69"/>
         <source>Source code</source>
         <translation>源代码</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="77"/>
+        <location filename="../aboutdialog.cpp" line="79"/>
         <source>Contributors</source>
         <translation>贡献者</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="79"/>
+        <location filename="../aboutdialog.cpp" line="81"/>
         <source>List of contributors on GitHub</source>
         <translation>GitHub 上的贡献者列表</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="80"/>
+        <location filename="../aboutdialog.cpp" line="82"/>
         <source>Thanks to all people who contributed to this project.</source>
         <translation>感谢所有参与此项目的朋友。</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="84"/>
+        <location filename="../aboutdialog.cpp" line="86"/>
         <source>Translators</source>
         <translation>翻译者</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="85"/>
+        <location filename="../aboutdialog.cpp" line="87"/>
         <source>I would like to thank the following people who volunteered to translate this application.</source>
         <translation>我想要感谢下列自愿参与翻译此应用程序的朋友。</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="129"/>
+        <location filename="../aboutdialog.cpp" line="131"/>
         <source>%1 is built on the following free software libraries:</source>
         <comment>Free as in freedom</comment>
         <translation>%1 采用了下列自由软件程序库进行构建：</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="153"/>
+        <location filename="../aboutdialog.cpp" line="155"/>
         <source>&amp;Special Thanks</source>
         <translation>致谢(&amp;S)</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="155"/>
+        <location filename="../aboutdialog.cpp" line="157"/>
         <source>&amp;Third-party Libraries</source>
         <translation>第三方程序库(&amp;T)</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="91"/>
+        <location filename="../aboutdialog.cpp" line="93"/>
         <source>Your Rights</source>
         <translation>用户的权利</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="46"/>
+        <location filename="../aboutdialog.cpp" line="48"/>
         <source>Avoid resetting the zoom/rotation/flip state that was applied to the image view when switching between images.</source>
         <translation>切换图片时，防止重置当前视图的缩放/旋转/翻转状态。</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="61"/>
+        <location filename="../aboutdialog.cpp" line="63"/>
         <source>Copyright (c) %1 %2</source>
         <comment>%1 is year, %2 is the name of copyright holder(s)</comment>
         <translation>版权所有 © %1 %2</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="93"/>
+        <location filename="../aboutdialog.cpp" line="95"/>
         <source>%1 is released under the MIT License.</source>
         <translation>%1 是在 MIT 许可协议下发布的。</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="94"/>
+        <location filename="../aboutdialog.cpp" line="96"/>
         <source>This license grants people a number of freedoms:</source>
         <translation>此许可证赋予人们以下自由的权利：</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="95"/>
+        <location filename="../aboutdialog.cpp" line="97"/>
         <source>You are free to use %1, for any purpose</source>
         <translation>任何人都可以为了任何目的自由地使用 %1</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="96"/>
+        <location filename="../aboutdialog.cpp" line="98"/>
         <source>You are free to distribute %1</source>
         <translation>任何人都可以自由地分发 %1</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="97"/>
+        <location filename="../aboutdialog.cpp" line="99"/>
         <source>You can study how %1 works and change it</source>
         <translation>任何人都可以自由地研究 %1 的工作原理并对其进行修改</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="98"/>
+        <location filename="../aboutdialog.cpp" line="100"/>
         <source>You can distribute changed versions of %1</source>
         <translation>任何人都可以自由地分发修改过的 %1 版本</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="100"/>
+        <location filename="../aboutdialog.cpp" line="102"/>
         <source>The MIT license guarantees you this freedom. Nobody is ever permitted to take it away.</source>
         <translation>此软件通过 MIT 许可证赋予用户上述自由，任何人无权剥夺。</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="128"/>
+        <location filename="../aboutdialog.cpp" line="130"/>
         <source>Third-party Libraries used by %1</source>
         <translation>%1 使用的第三方程序库</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="151"/>
+        <location filename="../aboutdialog.cpp" line="153"/>
         <source>&amp;Help</source>
         <translation>帮助(&amp;H)</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="152"/>
+        <location filename="../aboutdialog.cpp" line="154"/>
         <source>&amp;About</source>
         <translation>关于(&amp;A)</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="154"/>
+        <location filename="../aboutdialog.cpp" line="156"/>
         <source>&amp;License</source>
         <translation>软件许可证(&amp;L)</translation>
     </message>
@@ -178,7 +178,7 @@
 <context>
     <name>GraphicsScene</name>
     <message>
-        <location filename="../mainwindow.cpp" line="272"/>
+        <location filename="../mainwindow.cpp" line="276"/>
         <location filename="../graphicsscene.cpp" line="100"/>
         <source>Drag image here</source>
         <translation>拖放图片至此</translation>
@@ -191,13 +191,13 @@
         <translation type="vanished">文件 URL 列表为空</translation>
     </message>
     <message>
-        <location filename="../graphicsview.cpp" line="52"/>
+        <location filename="../graphicsview.cpp" line="50"/>
         <source>File is not a valid image</source>
         <translation>文件不是有效的图片文件</translation>
     </message>
     <message>
-        <location filename="../graphicsview.cpp" line="56"/>
-        <location filename="../graphicsview.cpp" line="60"/>
+        <location filename="../graphicsview.cpp" line="54"/>
+        <location filename="../graphicsview.cpp" line="58"/>
         <source>Image data is invalid or currently unsupported</source>
         <translation>图像数据无效或暂未支持</translation>
     </message>
@@ -213,38 +213,43 @@
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../mainwindow.cpp" line="180"/>
-        <location filename="../mainwindow.cpp" line="543"/>
+        <location filename="../mainwindow.cpp" line="181"/>
+        <location filename="../mainwindow.cpp" line="545"/>
         <source>File url list is empty</source>
         <translation>文件 URL 列表为空</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="441"/>
+        <location filename="../mainwindow.cpp" line="445"/>
         <source>&amp;Copy</source>
         <translation>复制(&amp;C)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="551"/>
+        <location filename="../mainwindow.cpp" line="553"/>
         <source>Image data is invalid</source>
         <translation>图片数据无效</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="558"/>
+        <location filename="../mainwindow.cpp" line="560"/>
         <source>Not supported mimedata: %1</source>
         <translation>不受支持的 MimeData 格式：%1</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="754"/>
+        <location filename="../mainwindow.cpp" line="759"/>
         <source>Image From Clipboard</source>
         <translation>剪切板图片</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="772"/>
+        <location filename="../mainwindow.cpp" line="777"/>
         <source>Are you sure you want to move &quot;%1&quot; to recycle bin?</source>
         <translation>您确认要将“%1”移动到回收站吗？</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="777"/>
+        <location filename="../mainwindow.cpp" line="781"/>
+        <source>Failed to move file to trash</source>
+        <translation>无法移动文件至回收站</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="782"/>
         <source>Move to trash failed, it might caused by file permission issue, file system limitation, or platform limitation.</source>
         <translation>移至回收站失败，这可能由文件权限、文件系统或平台限制导致。</translation>
     </message>
@@ -265,19 +270,19 @@
     </message>
     <message>
         <location filename="../actionmanager.cpp" line="118"/>
-        <location filename="../aboutdialog.cpp" line="39"/>
+        <location filename="../aboutdialog.cpp" line="41"/>
         <source>Stay on top</source>
         <translation>总在最前</translation>
     </message>
     <message>
         <location filename="../actionmanager.cpp" line="119"/>
-        <location filename="../aboutdialog.cpp" line="42"/>
+        <location filename="../aboutdialog.cpp" line="44"/>
         <source>Protected mode</source>
         <translation>保护模式</translation>
     </message>
     <message>
         <location filename="../actionmanager.cpp" line="120"/>
-        <location filename="../aboutdialog.cpp" line="45"/>
+        <location filename="../aboutdialog.cpp" line="47"/>
         <source>Keep transformation</source>
         <comment>The &apos;transformation&apos; means the flip/rotation status that currently applied to the image view</comment>
         <translation>保持视图变换</translation>
@@ -363,7 +368,7 @@
         <translation>下一个图像</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="771"/>
+        <location filename="../mainwindow.cpp" line="776"/>
         <location filename="../actionmanager.cpp" line="117"/>
         <source>Move to Trash</source>
         <translation>移至回收站</translation>
@@ -406,314 +411,314 @@
 <context>
     <name>MetadataModel</name>
     <message>
-        <location filename="../metadatamodel.cpp" line="41"/>
+        <location filename="../metadatamodel.cpp" line="43"/>
         <source>Origin</source>
         <comment>Section name.</comment>
         <translation>来源</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="42"/>
+        <location filename="../metadatamodel.cpp" line="44"/>
         <source>Image</source>
         <comment>Section name.</comment>
         <translation>图像</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="46"/>
+        <location filename="../metadatamodel.cpp" line="48"/>
         <source>File</source>
         <comment>Section name.</comment>
         <translation>文件</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="43"/>
+        <location filename="../metadatamodel.cpp" line="45"/>
         <source>Camera</source>
         <comment>Section name.</comment>
         <translation>照相机</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="33"/>
+        <location filename="../metadatamodel.cpp" line="35"/>
         <source>%1 File</source>
         <translation>%1 文件</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="40"/>
+        <location filename="../metadatamodel.cpp" line="42"/>
         <source>Description</source>
         <comment>Section name.</comment>
         <translation>说明</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="44"/>
+        <location filename="../metadatamodel.cpp" line="46"/>
         <source>Advanced photo</source>
         <comment>Section name.</comment>
         <translation>高级照片</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="45"/>
+        <location filename="../metadatamodel.cpp" line="47"/>
         <source>GPS</source>
         <comment>Section name.</comment>
         <translation>GPS</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="50"/>
+        <location filename="../metadatamodel.cpp" line="52"/>
         <source>Dimensions</source>
         <translation>分辨率</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="52"/>
+        <location filename="../metadatamodel.cpp" line="54"/>
         <source>Aspect ratio</source>
         <translation>纵横比</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="56"/>
+        <location filename="../metadatamodel.cpp" line="58"/>
         <source>Frame count</source>
         <translation>总帧数</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="60"/>
+        <location filename="../metadatamodel.cpp" line="62"/>
         <source>Name</source>
         <translation>名称</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="62"/>
+        <location filename="../metadatamodel.cpp" line="64"/>
         <source>Item type</source>
         <translation>项目类型</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="64"/>
+        <location filename="../metadatamodel.cpp" line="66"/>
         <source>Folder path</source>
         <translation>文件夹路径</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="66"/>
+        <location filename="../metadatamodel.cpp" line="68"/>
         <source>Size</source>
         <translation>大小</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="68"/>
+        <location filename="../metadatamodel.cpp" line="70"/>
         <source>Date created</source>
         <translation>创建日期</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="70"/>
+        <location filename="../metadatamodel.cpp" line="72"/>
         <source>Date modified</source>
         <translation>修改日期</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="77"/>
+        <location filename="../metadatamodel.cpp" line="79"/>
         <source>Title</source>
         <translation>标题</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="79"/>
+        <location filename="../metadatamodel.cpp" line="81"/>
         <source>Subject</source>
         <translation>主题</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="81"/>
+        <location filename="../metadatamodel.cpp" line="83"/>
         <source>Rating</source>
         <translation>评分</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="83"/>
+        <location filename="../metadatamodel.cpp" line="85"/>
         <source>Tags</source>
         <translation>标记</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="85"/>
+        <location filename="../metadatamodel.cpp" line="87"/>
         <source>Comments</source>
         <translation>备注</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="88"/>
+        <location filename="../metadatamodel.cpp" line="90"/>
         <source>Authors</source>
         <translation>作者</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="90"/>
+        <location filename="../metadatamodel.cpp" line="92"/>
         <source>Date taken</source>
         <translation>拍摄日期</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="96"/>
+        <location filename="../metadatamodel.cpp" line="98"/>
         <source>Program name</source>
         <translation>程序名称</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="98"/>
+        <location filename="../metadatamodel.cpp" line="100"/>
         <source>Copyright</source>
         <translation>版权</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="101"/>
+        <location filename="../metadatamodel.cpp" line="103"/>
         <source>Horizontal resolution</source>
         <translation>水平分辨率</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="103"/>
+        <location filename="../metadatamodel.cpp" line="105"/>
         <source>Vertical resolution</source>
         <translation>垂直分辨率</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="105"/>
+        <location filename="../metadatamodel.cpp" line="107"/>
         <source>Resolution unit</source>
         <translation>分辨率单位</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="107"/>
+        <location filename="../metadatamodel.cpp" line="109"/>
         <source>Colour representation</source>
         <translation>色彩空间</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="110"/>
+        <location filename="../metadatamodel.cpp" line="112"/>
         <source>Camera maker</source>
         <translation>照相机制造商</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="112"/>
+        <location filename="../metadatamodel.cpp" line="114"/>
         <source>Camera model</source>
         <translation>照相机型号</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="114"/>
+        <location filename="../metadatamodel.cpp" line="116"/>
         <source>F-stop</source>
         <translation>光圈值</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="116"/>
+        <location filename="../metadatamodel.cpp" line="118"/>
         <source>Exposure time</source>
         <translation>曝光时间</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="118"/>
+        <location filename="../metadatamodel.cpp" line="120"/>
         <source>ISO speed</source>
         <translation>ISO 感光度</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="120"/>
+        <location filename="../metadatamodel.cpp" line="122"/>
         <source>Exposure bias</source>
         <translation>曝光补偿</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="122"/>
+        <location filename="../metadatamodel.cpp" line="124"/>
         <source>Focal length</source>
         <translation>焦距</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="124"/>
+        <location filename="../metadatamodel.cpp" line="126"/>
         <source>Max aperture</source>
         <translation>镜头最大光圈</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="126"/>
+        <location filename="../metadatamodel.cpp" line="128"/>
         <source>Metering mode</source>
         <translation>测光模式</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="128"/>
+        <location filename="../metadatamodel.cpp" line="130"/>
         <source>Subject distance</source>
         <translation>目标距离</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="130"/>
+        <location filename="../metadatamodel.cpp" line="132"/>
         <source>Flash mode</source>
         <translation>闪光灯模式</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="132"/>
+        <location filename="../metadatamodel.cpp" line="134"/>
         <source>35mm focal length</source>
         <translation>换算至 35mm 焦距</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="135"/>
+        <location filename="../metadatamodel.cpp" line="137"/>
         <source>Lens model</source>
         <translation>镜头型号</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="137"/>
+        <location filename="../metadatamodel.cpp" line="139"/>
         <source>Contrast</source>
         <translation>对比度</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="139"/>
+        <location filename="../metadatamodel.cpp" line="141"/>
         <source>Brightness</source>
         <translation>亮度</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="141"/>
+        <location filename="../metadatamodel.cpp" line="143"/>
         <source>Exposure program</source>
         <translation>曝光程序</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="143"/>
+        <location filename="../metadatamodel.cpp" line="145"/>
         <source>Saturation</source>
         <translation>饱和度</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="145"/>
+        <location filename="../metadatamodel.cpp" line="147"/>
         <source>Sharpness</source>
         <translation>锐度</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="147"/>
+        <location filename="../metadatamodel.cpp" line="149"/>
         <source>White balance</source>
         <translation>白平衡</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="149"/>
+        <location filename="../metadatamodel.cpp" line="151"/>
         <source>Digital zoom</source>
         <translation>数码变焦倍率</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="151"/>
+        <location filename="../metadatamodel.cpp" line="153"/>
         <source>EXIF version</source>
         <translation>EXIF 版本</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="154"/>
+        <location filename="../metadatamodel.cpp" line="156"/>
         <source>Latitude reference</source>
         <translation>纬度基准</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="156"/>
+        <location filename="../metadatamodel.cpp" line="158"/>
         <source>Latitude</source>
         <translation>纬度</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="158"/>
+        <location filename="../metadatamodel.cpp" line="160"/>
         <source>Longitude reference</source>
         <translation>经度基准</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="160"/>
+        <location filename="../metadatamodel.cpp" line="162"/>
         <source>Longitude</source>
         <translation>经度</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="162"/>
+        <location filename="../metadatamodel.cpp" line="164"/>
         <source>Altitude reference</source>
         <translation>海拔基准</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="164"/>
+        <location filename="../metadatamodel.cpp" line="166"/>
         <source>Altitude</source>
         <translation>海拔</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="174"/>
+        <location filename="../metadatamodel.cpp" line="176"/>
         <source>%1 x %2</source>
         <translation>%1 x %2</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="192"/>
+        <location filename="../metadatamodel.cpp" line="194"/>
         <source>%1 : %2</source>
         <translation>%1 : %2</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="317"/>
+        <location filename="../metadatamodel.cpp" line="319"/>
         <source>Property</source>
         <translation>属性</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="317"/>
+        <location filename="../metadatamodel.cpp" line="319"/>
         <source>Value</source>
         <translation>值</translation>
     </message>
@@ -721,131 +726,141 @@
 <context>
     <name>SettingsDialog</name>
     <message>
-        <location filename="../settingsdialog.cpp" line="29"/>
+        <location filename="../settingsdialog.cpp" line="31"/>
         <source>Settings</source>
         <translation>设定</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="37"/>
+        <location filename="../settingsdialog.cpp" line="39"/>
         <source>Options</source>
         <translation>选项</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="49"/>
+        <location filename="../settingsdialog.cpp" line="51"/>
         <source>Shortcuts</source>
         <translation>快捷键</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="59"/>
+        <location filename="../settingsdialog.cpp" line="61"/>
         <source>Editing shortcuts for action &quot;%1&quot;:</source>
         <translation>编辑“%1”的快捷键：</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="68"/>
+        <location filename="../settingsdialog.cpp" line="70"/>
         <source>Failed to set shortcuts</source>
         <translation>快捷键设置失败</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="69"/>
+        <location filename="../settingsdialog.cpp" line="71"/>
         <source>Please check if shortcuts are duplicated with existing shortcuts.</source>
         <translation>请检查快捷键是否与现有快捷键冲突。</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="76"/>
+        <location filename="../settingsdialog.cpp" line="78"/>
         <source>Do nothing</source>
         <translation>什么也不做</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="77"/>
+        <location filename="../settingsdialog.cpp" line="79"/>
         <source>Close the window</source>
         <translation>关闭窗口</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="78"/>
+        <location filename="../settingsdialog.cpp" line="80"/>
         <source>Toggle maximize</source>
         <translation>最大化窗口</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="79"/>
+        <location filename="../settingsdialog.cpp" line="81"/>
         <source>Toggle fullscreen</source>
         <translation>全屏窗口</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="83"/>
+        <location filename="../settingsdialog.cpp" line="85"/>
         <source>Zoom in and out</source>
         <translation>放大和缩小</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="84"/>
+        <location filename="../settingsdialog.cpp" line="86"/>
         <source>View next or previous item</source>
         <translation>查看下一项或上一项</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="88"/>
+        <location filename="../settingsdialog.cpp" line="90"/>
         <source>Auto size</source>
         <translation>自动大小</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="89"/>
+        <location filename="../settingsdialog.cpp" line="91"/>
         <source>Maximized</source>
         <translation>最大化</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="90"/>
+        <location filename="../settingsdialog.cpp" line="92"/>
         <source>Windowed</source>
         <translation>窗口化</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="94"/>
+        <location filename="../settingsdialog.cpp" line="96"/>
         <source>Round (Integer scaling)</source>
         <comment>This option means round up for .5 and above</comment>
         <translation>四舍五入（整数缩放）</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="95"/>
+        <location filename="../settingsdialog.cpp" line="97"/>
         <source>Ceil (Integer scaling)</source>
         <comment>This option means always round up</comment>
         <translation>向上取整（整数缩放）</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="96"/>
+        <location filename="../settingsdialog.cpp" line="98"/>
         <source>Floor (Integer scaling)</source>
         <comment>This option means always round down</comment>
         <translation>向下取整（整数缩放）</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="97"/>
+        <location filename="../settingsdialog.cpp" line="99"/>
         <source>Follow system (Fractional scaling)</source>
         <comment>This option means don&apos;t round</comment>
         <translation>跟随系统（小数缩放）</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="120"/>
+        <location filename="../settingsdialog.cpp" line="122"/>
         <source>Stay on top when start-up</source>
         <translation>启动时保持窗口总在最前</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="121"/>
+        <location filename="../settingsdialog.cpp" line="123"/>
+        <source>Use built-in close window animation</source>
+        <translation>使用内置的关闭窗口动画</translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.cpp" line="124"/>
         <source>Use light-color checkerboard</source>
         <translation>使用亮色棋盘格</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="122"/>
+        <location filename="../settingsdialog.cpp" line="125"/>
+        <source>Loop the loaded gallery</source>
+        <translation>循环所加载的图像列表</translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.cpp" line="126"/>
         <source>Double-click behavior</source>
         <translation>双击时的行为</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="123"/>
+        <location filename="../settingsdialog.cpp" line="127"/>
         <source>Mouse wheel behavior</source>
         <translation>鼠标滚轮行为</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="124"/>
+        <location filename="../settingsdialog.cpp" line="128"/>
         <source>Default window size</source>
         <translation>默认窗口大小</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="125"/>
+        <location filename="../settingsdialog.cpp" line="129"/>
         <source>HiDPI scale factor rounding policy</source>
         <translation>HiDPI 高分屏缩放策略</translation>
     </message>
@@ -853,7 +868,7 @@
 <context>
     <name>ShortcutEdit</name>
     <message>
-        <location filename="../shortcutedit.cpp" line="111"/>
+        <location filename="../shortcutedit.cpp" line="109"/>
         <source>No shortcuts</source>
         <translation>无快捷键</translation>
     </message>
@@ -861,7 +876,7 @@
 <context>
     <name>ShortcutEditor</name>
     <message>
-        <location filename="../shortcutedit.cpp" line="77"/>
+        <location filename="../shortcutedit.cpp" line="75"/>
         <source>Shortcut #%1</source>
         <translation>快捷键 %1</translation>
     </message>
@@ -869,17 +884,17 @@
 <context>
     <name>main</name>
     <message>
-        <location filename="../main.cpp" line="43"/>
+        <location filename="../main.cpp" line="42"/>
         <source>Pineapple Pictures</source>
         <translation>菠萝看图</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="46"/>
+        <location filename="../main.cpp" line="45"/>
         <source>List supported image format suffixes, and quit program.</source>
         <translation>列出所支持的图像格式扩展名，并退出程序。</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="50"/>
+        <location filename="../main.cpp" line="49"/>
         <source>File list.</source>
         <translation>文件列表。</translation>
     </message>
